==> azureml_automl_dnn_nlp-1.24.0-py3-none-any.whl: azureml/automl/dnn/nlp/classification/io/read/dataloader.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Contains dataloader functions for the classification tasks."""

from azureml.core import Dataset as AmlDataset

import logging
import numpy as np
import pandas as pd
from sklearn.feature_extraction.text import CountVectorizer

from azureml.automl.dnn.nlp.classification.io.read.pytorch_dataset_wrapper import PyTorchDatasetWrapper
from azureml.automl.dnn.nlp.classification.common.constants import DatasetLiterals
from azureml.automl.dnn.nlp.classification.io.write.save_utils import save_vectorizer


_logger = logging.getLogger(__name__)


def convert_dataset_format(train_df, val_df):
    """Converting dataset format for consumption during model training.

    :param train_df: Training DataFrame
    :type train_df: pd.DataFrame
    :param val_df: Validation DataFrame
    :type val_df: pd.DataFrame
    :return: training df, validation df, number of label columns
    :rtype: pd.DataFrame, pd.DataFrame, int
    """
    # Combine both dataframes
    combined_df = pd.concat([train_df, val_df])

    # Get combined label column
    combined_label_col = np.array(combined_df[DatasetLiterals.LABEL_COLUMN].astype(str))

    # TODO: CountVectorizer could run into memory issues for large datasets
    vectorizer = CountVectorizer()
    vectorizer.fit(combined_label_col)
    save_vectorizer(vectorizer)

    train_label_col = np.array(train_df[DatasetLiterals.LABEL_COLUMN].astype(str))
    val_label_col = np.array(val_df[DatasetLiterals.LABEL_COLUMN].astype(str))

    train_count_array = vectorizer.transform(train_label_col)
    val_count_array = vectorizer.transform(val_label_col)

    # Create dataframes with label columns
    train_labels_df = pd.DataFrame(train_count_array.toarray().astype(float))
    train_labels_df.columns = vectorizer.get_feature_names()

    val_labels_df = pd.DataFrame(val_count_array.toarray().astype(float))
    val_labels_df.columns = vectorizer.get_feature_names()

    # Create result dataframe by concatenating text with label dataframe
    train_res_df = pd.concat([train_df[DatasetLiterals.TEXT_COLUMN], train_labels_df], join='outer', axis=1)
    val_res_df = pd.concat([val_df[DatasetLiterals.TEXT_COLUMN], val_labels_df], join='outer', axis=1)

    num_label_cols = len(train_res_df.columns) - 1
    _logger.info("Number of label columns is: {}".format(num_label_cols))
    _logger.info("Train Dataframe obtained has columns: {}".format(train_res_df.columns))
    _logger.info("Train Dataframe has shape: {}".format(train_res_df.shape))

    t_df = train_res_df
    t_df['list'] = train_res_df[train_res_df.columns[1:]].values.tolist()
    t_df = t_df[[DatasetLiterals.TEXT_COLUMN, 'list']].copy()

    v_df = val_res_df
    v_df['list'] = val_res_df[val_res_df.columns[1:]].values.tolist()
    v_df = v_df[[DatasetLiterals.TEXT_COLUMN, 'list']].copy()

    return t_df, v_df, num_label_cols


def dataset_loader(dataset_id, validation_dataset_id, workspace):
    """Save checkpoint to outputs directory.

    :param dataset_id: Unique identifier to fetch dataset from datastore
    :type dataset_id: string
    :param validation_dataset_id: Unique identifier to fetch validation dataset from datastore
    :type validation_dataset_id: string
    :param workspace: workspace where dataset is stored in blob
    :type workspace: Workspace
    :return: training dataset, test datasets, number of label columns
    :rtype: PyTorchDatasetWrapper, PyTorchDatasetWrapper, int
    """

    # Get Training Dataset object
    train_ds = AmlDataset.get_by_id(workspace, dataset_id)
    _logger.info("Type of Dataset is: {}".format(type(train_ds)))

    # Get Validation Dataset object
    validation_ds = AmlDataset.get_by_id(workspace, validation_dataset_id)
    _logger.info("Type of Validation Dataset is: {}".format(type(validation_ds)))

    # Convert Dataset to Dataframe and convert to format required by model
    train_df = train_ds.to_pandas_dataframe()
    validation_df = validation_ds.to_pandas_dataframe()

    t_df, v_df, num_label_cols = convert_dataset_format(train_df, validation_df)

    _logger.info("TRAIN Dataset: {}".format(t_df.shape))
    _logger.info("VALIDATION Dataset: {}".format(v_df.shape))

    training_set = PyTorchDatasetWrapper(t_df)
    validation_set = PyTorchDatasetWrapper(v_df)

    return training_set, validation_set, num_label_cols

==> azureml_automl_dnn_nlp-1.28.0-py3-none-any.whl: azureml/automl/dnn/nlp/classification/io/read/dataloader.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------

"""Contains dataloader functions for the classification tasks."""

import logging
import numpy as np
import pandas as pd

from sklearn.feature_extraction.text import CountVectorizer
from typing import Tuple

from azureml.automl.dnn.nlp.classification.io.read.pytorch_dataset_wrapper import PyTorchDatasetWrapper
from azureml.automl.dnn.nlp.classification.common.constants import DatasetLiterals
from azureml.automl.dnn.nlp.classification.io.write.save_utils import save_vectorizer
from azureml.core import Dataset as AmlDataset
from azureml.core.workspace import Workspace


_logger = logging.getLogger(__name__)


def get_vectorizer(train_df: pd.DataFrame, val_df: pd.DataFrame) -> CountVectorizer:
    """Obtain labels vectorizer

    :param train_df: Training DataFrame
    :param val_df: Validation DataFrame
    :return: vectorizer
    """
    # Combine both dataframes
    combined_df = pd.concat([train_df, val_df])

    # Get combined label column
    combined_label_col = np.array(combined_df[DatasetLiterals.LABEL_COLUMN].astype(str))

    # TODO: CountVectorizer could run into memory issues for large datasets
    vectorizer = CountVectorizer()
    vectorizer.fit(combined_label_col)
    save_vectorizer(vectorizer)

    return vectorizer


def convert_dataset_format(df: pd.DataFrame, vectorizer: CountVectorizer) -> pd.DataFrame:
    """Converting dataset format for consumption during model training.
    The input dataframe contains a single labels columns with comma separated labels per datapoint.
    The vectorizer is used to generate multiple label columns from the combined labels column.

    :param df: Dataframe to be converted into required format
    :param vectorizer: labels vectorizer
    :return: Dataframe in required format
    """
    label_col = np.array(df[DatasetLiterals.LABEL_COLUMN].astype(str))

    # Create dataframes with label columns
    count_array = vectorizer.transform(label_col)
    labels_df = pd.DataFrame(count_array.toarray().astype(float))
    labels_df.columns = vectorizer.get_feature_names()

    # Create result dataframe by concatenating text with label dataframe
    res_df = pd.concat([df[DatasetLiterals.TEXT_COLUMN], labels_df], join='outer', axis=1)

    final_df = res_df
    final_df['list'] = res_df[res_df.columns[1:]].values.tolist()
    final_df = final_df[[DatasetLiterals.TEXT_COLUMN, 'list']].copy()

    return final_df


def dataset_loader(dataset_id: str,
                   validation_dataset_id: str,
                   workspace: Workspace) -> Tuple[PyTorchDatasetWrapper, PyTorchDatasetWrapper, int]:
    """Save checkpoint to outputs directory.

    :param dataset_id: Unique identifier to fetch dataset from datastore
    :param validation_dataset_id: Unique identifier to fetch validation dataset from datastore
    :param workspace: workspace where dataset is stored in blob
    :return: training dataset, test datasets, number of label columns
    """

    # Get Training Dataset object
    train_ds = AmlDataset.get_by_id(workspace, dataset_id)
    _logger.info("Type of Dataset is: {}".format(type(train_ds)))

    # Get Validation Dataset object
    validation_ds = AmlDataset.get_by_id(workspace, validation_dataset_id)
    _logger.info("Type of Validation Dataset is: {}".format(type(validation_ds)))

    # Convert Dataset to Dataframe and convert to format required by model
    train_df = train_ds.to_pandas_dataframe()
    validation_df = validation_ds.to_pandas_dataframe()

    vectorizer = get_vectorizer(train_df, validation_df)
    num_label_cols = len(vectorizer.get_feature_names())

    t_df = convert_dataset_format(train_df, vectorizer)
    v_df = convert_dataset_format(validation_df, vectorizer)

    _logger.info("TRAIN Dataset: {}".format(t_df.shape))
    _logger.info("VALIDATION Dataset: {}".format(v_df.shape))

    training_set = PyTorchDatasetWrapper(t_df)
    validation_set = PyTorchDatasetWrapper(v_df)

    return training_set, validation_set, num_label_cols
